@@ -1,15 +1,17 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MungeFile::WithConfigFile; # git description: v0.003-2-g068a2cc
+package Dist::Zilla::Plugin::MungeFile::WithConfigFile; # git description: v0.004-10-g4d7a072
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Modify files in the build, with templates and config data from a file
 # KEYWORDS: plugin file content injection modification template configuration file
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::MungeFile';
 with 'MooseX::SimpleConfig';
+
+use Path::Tiny;
 use namespace::autoclean;
 
 has configfile => (
@@ -22,7 +24,7 @@ has _config_data => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        $self->get_config_from_file($self->configfile);
+        $self->get_config_from_file(path($self->configfile)->absolute($self->zilla->root));
     },
 );
 
@@ -33,7 +35,7 @@ around dump_config => sub
 
     my $config = $self->$orig;
 
-    $config->{'' . __PACKAGE__} = {
+    $config->{+__PACKAGE__} = {
         configfile => $self->configfile,
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
@@ -65,7 +67,7 @@ Dist::Zilla::Plugin::MungeFile::WithConfigFile - Modify files in the build, with
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -129,7 +131,7 @@ There is no default.
 
 =head2 C<file>
 
-Indicates the filename in the dist to be operated upon; this file can exist on
+Indicates the filename in the distribution to be operated upon; this file can exist on
 disk, or have been generated by some other plugin.  Can be included more than once.
 
 B<At least one of the C<finder> or C<file> options is required.>
@@ -145,14 +147,6 @@ UTF-8), so any extracted strings should be appropriately decoded first. This
 is an issue that needs to be resolved in L<Config::Any> (perhaps by having the
 caller, in our case L<MooseX::SimpleConfig>, to pass the desired decoding).
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-MungeFile-WithConfigFile>
-(or L<bug-Dist-Zilla-Plugin-MungeFile-WithConfigFile@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-MungeFile-WithConfigFile@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -175,6 +169,19 @@ L<Dist::Zilla::Plugin::MungeFile::WithDataSection>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-MungeFile-WithConfigFile>
+(or L<bug-Dist-Zilla-Plugin-MungeFile-WithConfigFile@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-MungeFile-WithConfigFile@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
